@@ -7,30 +7,11 @@
 # include <config.h>
 #endif
 
-#ifdef HAVE_BYTESWAP_H
-# include <byteswap.h>
-#endif
-
-#ifdef HAVE_READDIR_R
-# define _POSIX_C_SOURCE 199506L
-#endif
 
 #ifdef HAVE_SYS_TYPES_H
 # include <sys/types.h>
 #endif
 
-#ifdef HAVE_SYS_ENDIAN_H
-# include <sys/endian.h>
-#endif
-
-#ifdef HAVE_MACHINE_ENDIAN_H
-# include <machine/endian.h>
-#endif
-
-#ifdef HAVE_ENDIAN_H
-# include <endian.h>
-#endif
-
 #include "win32_comp.h"
 
 #ifdef USE_LTDL
@@ -61,10 +42,6 @@
 # include <string.h>
 #endif
 
-#ifdef HAVE_DIRENT_H
-# include <dirent.h>
-#endif
-
 #ifdef HAVE_STRINGS_H
 # include <strings.h>
 #endif
@@ -73,8 +50,29 @@
 # include <unistd.h>
 #endif
 
-#ifdef HAVE_LIBPTHREAD
-# include <pthread.h>
+#ifdef HAVE_SYS_ENDIAN_H
+# include <sys/endian.h>
+#endif
+
+#ifdef HAVE_MACHINE_ENDIAN_H
+# include <machine/endian.h>
+#endif
+
+#ifdef HAVE_ENDIAN_H
+# include <endian.h>
+#endif
+
+#ifdef HAVE_BYTESWAP_H
+# include <byteswap.h>
+#endif
+
+
+#ifdef HAVE_READDIR_R
+# define _POSIX_C_SOURCE 199506L
+#endif
+
+#ifdef HAVE_DIRENT_H
+# include <dirent.h>
 #endif
 
 #if SIZEOF_UNSIGNED_LONG_INT == 4
