@@ -181,6 +181,7 @@ MCRYPT mcrypt_module_open(char *algorithm,
 			fputs("\n", stderr);
 		}
 		free(td);
+		lt_dlexit();
 		return MCRYPT_FAILED;
 	}
 
@@ -194,6 +195,7 @@ MCRYPT mcrypt_module_open(char *algorithm,
 		}
 		mcrypt_dlclose(td->algorithm_handle);
 		free(td);
+		lt_dlexit();
 		return MCRYPT_FAILED;
 	}
 
@@ -213,6 +215,7 @@ MCRYPT mcrypt_module_open(char *algorithm,
 		}
 		mcrypt_dlclose(td->algorithm_handle);
 		free(td);
+		lt_dlexit();
 		return MCRYPT_FAILED;
 	}
 
@@ -439,7 +442,7 @@ char *mcrypt_enc_get_algorithms_name(MCRYPT td)
 		return NULL;
 	}
 
-	return (char*) strdup(_mcrypt_get_algorithms_name());
+	return strdup(_mcrypt_get_algorithms_name());
 }
 
 WIN32DLL_DEFINE
@@ -516,7 +519,7 @@ char *mcrypt_enc_get_modes_name(MCRYPT td)
 		return NULL;
 	}
 
-	return (char*) strdup(_mcrypt_get_modes_name());
+	return strdup(_mcrypt_get_modes_name());
 }
 
 WIN32DLL_DEFINE
@@ -698,6 +701,7 @@ int mcrypt_module_mode_version(char *mode, char *m_directory)
 			fputs(error, stderr);
 			fputs("\n", stderr);
 		}
+		lt_dlexit();
 		return MCRYPT_UNKNOWN_ERROR;
 	}
 
@@ -738,6 +742,7 @@ int mcrypt_module_is_block_algorithm(char *algorithm, char *a_directory)
 			fputs( error, stderr);
 			fputs("\n", stderr);
 		}
+		lt_dlexit();
 		return MCRYPT_UNKNOWN_ERROR;
 	}
 
@@ -778,6 +783,7 @@ int mcrypt_module_is_block_algorithm_mode(char *mode, char *m_directory)
 			fputs( error, stderr);
 			fputs("\n", stderr);
 		}
+		lt_dlexit();
 		return MCRYPT_UNKNOWN_ERROR;
 	}
 
@@ -818,6 +824,7 @@ int mcrypt_module_is_block_mode(char *mode, char *m_directory)
 			fputs( error, stderr);
 			fputs("\n", stderr);
 		}
+		lt_dlexit();
 		return MCRYPT_UNKNOWN_ERROR;
 	}
 
@@ -858,6 +865,7 @@ int mcrypt_module_get_algo_block_size(char *algorithm, char *a_directory)
 			fputs( error, stderr);
 			fputs("\n", stderr);
 		}
+		lt_dlexit();
 		return MCRYPT_UNKNOWN_ERROR;
 	}
 
@@ -898,6 +906,7 @@ int mcrypt_module_get_algo_key_size(char *algorithm, char *a_directory)
 			fputs( error, stderr);
 			fputs("\n", stderr);
 		}
+		lt_dlexit();
 		return MCRYPT_UNKNOWN_ERROR;
 	}
 
@@ -929,6 +938,7 @@ int *mcrypt_module_get_algo_supported_key_sizes(char *algorithm,
 	int * ret_size;
 	const char* error;
 	void * rr;
+
 	
 	if (lt_dlinit() != 0) {
 		*len = 0;
@@ -942,6 +952,7 @@ int *mcrypt_module_get_algo_supported_key_sizes(char *algorithm,
 			fputs( error, stderr);
 			fputs("\n", stderr);
 		}
+		lt_dlexit();
 		*len = 0;
 		return NULL;
 	}
@@ -951,6 +962,7 @@ int *mcrypt_module_get_algo_supported_key_sizes(char *algorithm,
 	if (_mcrypt_get_key_sizes==NULL) {
 		mcrypt_dlclose(_handle);
 		lt_dlexit();
+		*len = 0;
 		return NULL;
 	}
 
@@ -961,7 +973,7 @@ int *mcrypt_module_get_algo_supported_key_sizes(char *algorithm,
 		if (ret_size!=NULL) {
 			memcpy( ret_size, size, (*len)*sizeof(int));
 		}
-	}
+	} else *len = 0;
 	
 	mcrypt_dlclose(_handle);
 	if (lt_dlexit() != 0) {
