@@ -7,10 +7,11 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: blowfish.c,v 1.15 2001/05/16 17:54:25 nmav Exp $ */
+/* $Id: blowfish.c,v 1.18 2001/09/09 09:52:54 nmav Exp $ */
 
-#include "../../lib/libdefs.h"
-#include "../../lib/mcrypt_modules.h"
+#include <libdefs.h>
+
+#include <mcrypt_modules.h>
 #include "blowfish.h"
 
 #ifdef USE_LTDL
@@ -581,17 +582,14 @@ WIN32DLL_DEFINE int _mcrypt_get_key_size()
 {
 	return 56;
 }
-WIN32DLL_DEFINE int *_mcrypt_get_supported_key_sizes(int *len)
+WIN32DLL_DEFINE const int *_mcrypt_get_supported_key_sizes(int *len)
 {
 	*len = 0;
 	return NULL;
 }
 WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
 {
-	char *x;
-	x = malloc(10);
-	strcpy(x, "Blowfish");
-	return x;
+return "Blowfish";
 }
 
 #define CIPHER "c8c033bc57874d74"
@@ -652,5 +650,5 @@ WIN32DLL_DEFINE int _mcrypt_self_test()
 
 WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
 {
-	return 20010111;
+	return 20010801;
 }
