@@ -20,7 +20,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: twofish.c,v 1.7 2001/05/16 17:54:25 nmav Exp $ */
+/* $Id: twofish.c,v 1.10 2001/09/09 09:52:55 nmav Exp $ */
 
 /* Timing data for Twofish (twofish.c)
 
@@ -44,8 +44,9 @@
 
  */
 
-#include "../../lib/libdefs.h"
-#include "../../lib/mcrypt_modules.h"
+#include <libdefs.h>
+
+#include <mcrypt_modules.h>
 #include "twofish.h"
 
 #ifdef USE_LTDL
@@ -591,22 +592,16 @@ WIN32DLL_DEFINE int _mcrypt_get_key_size()
 	return 32;
 }
 
-WIN32DLL_DEFINE int *_mcrypt_get_supported_key_sizes(int *len)
+static const int key_sizes[] = { 16, 24, 32 };
+WIN32DLL_DEFINE const int *_mcrypt_get_supported_key_sizes(int *len)
 {
-	int *size = malloc(3 * sizeof(int));
-	size[0] = 16;
-	size[1] = 24;
-	size[2] = 32;
-	*len = 3;
-	return size;
+	*len = sizeof(key_sizes)/sizeof(int);
+	return key_sizes;
 }
 
-WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
+WIN32DLL_DEFINE const char *_mcrypt_get_algorithms_name()
 {
-	char *x;
-	x = malloc(10);
-	strcpy(x, "Twofish");
-	return x;
+return "Twofish";
 }
 
 #define CIPHER "cc1c778374bccd6e73bfc642384cef7d"
