@@ -59,20 +59,22 @@ int main()
 			x=1;
 			printf( "\n");
 		}
-
 		printf( "Modes:\n");
 			for (i=0;i<imax;i++) {
 				td = mcrypt_module_open(names[j], ALGORITHMS_DIR, modes[i], MODES_DIR);
 				td2 = mcrypt_module_open(names[j], ALGORITHMS_DIR, modes[i], MODES_DIR);
-				if (td != MCRYPT_FAILED) {
+				if (td != MCRYPT_FAILED && td2 != MCRYPT_FAILED) {
 					keysize = mcrypt_enc_get_key_size(td);
 					key = calloc(1, keysize);
+					if (key==NULL) exit(1);
+					
 					for (t=0;t<keysize;t++)
 						key[t] = (t % 255) + 13;
 					
 					ivsize = mcrypt_enc_get_iv_size(td);
 					if (ivsize>0) {
 						IV = calloc( 1, ivsize);
+						if (IV==NULL) exit(1);
 						for (t=0;t<ivsize;t++)
 							IV[t] = (t*2 % 255) + 15;
 					}
@@ -83,6 +85,8 @@ int main()
 
 					siz = (strlen(TEXT) / mcrypt_enc_get_block_size(td))*mcrypt_enc_get_block_size(td);
 					text = calloc( 1, siz);
+					if (text==NULL) exit(1);
+					
 					memmove( text, TEXT, siz);
 
 					mcrypt_generic( td, text, siz);
